summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmactions.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:00 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:00 -0600
commitec1fddcd0d6663ad273af85357f04abbc5689468 (patch)
tree6cb946ab8b4771868c6eee8d1aa5213d6ec246e2 /kpovmodeler/pmactions.cpp
parentc2637a0da6d9a1c8626ca39f8451ab3b7cda487a (diff)
downloadtdegraphics-ec1fddcd0d6663ad273af85357f04abbc5689468.tar.gz
tdegraphics-ec1fddcd0d6663ad273af85357f04abbc5689468.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit c2637a0da6d9a1c8626ca39f8451ab3b7cda487a.
Diffstat (limited to 'kpovmodeler/pmactions.cpp')
-rw-r--r--kpovmodeler/pmactions.cpp20
1 files changed, 10 insertions, 10 deletions
diff --git a/kpovmodeler/pmactions.cpp b/kpovmodeler/pmactions.cpp
index 0229c518..18af4c37 100644
--- a/kpovmodeler/pmactions.cpp
+++ b/kpovmodeler/pmactions.cpp
@@ -29,7 +29,7 @@
#include "pmdebug.h"
// Fixed widths are calculated wrong in a toolbar.
// Fixed sizeHint for the combo box to return
// at least the minimum size
class PMComboBox : public TQComboBox
{
@@ -39,15 +39,15 @@ public:
{
}
- virtual TQSize minimumSizeHint( ) const
+ virtual TQSize tqminimumSizeHint( ) const
{
- TQSize s = TQComboBox::minimumSizeHint( );
- return s.expandedTo( minimumSize( ) );
+ TQSize s = TQComboBox::tqminimumSizeHint( );
+ return s.expandedTo( tqminimumSize( ) );
}
- virtual TQSize sizeHint( ) const
+ virtual TQSize tqsizeHint( ) const
{
- TQSize s = TQComboBox::sizeHint( );
- return s.expandedTo( minimumSize( ) );
+ TQSize s = TQComboBox::tqsizeHint( );
+ return s.expandedTo( tqminimumSize( ) );
}
};
@@ -126,7 +126,7 @@ public:
setText( text );
}
protected:
- TQSize sizeHint( ) const
+ TQSize tqsizeHint( ) const
{
int w = fontMetrics( ).width( text( ) );
int h = fontMetrics( ).height( );
@@ -135,10 +135,10 @@ protected:
void drawButton( TQPainter* p )
{
// Draw the background
- tqstyle( ).drawComplexControl( TQStyle::CC_ToolButton, p, this, rect( ), colorGroup( ),
+ tqstyle( ).tqdrawComplexControl( TQStyle::CC_ToolButton, p, this, rect( ), tqcolorGroup( ),
TQStyle::Style_Enabled, TQStyle::SC_ToolButton );
// Draw the label
- tqstyle( ).drawControl( TQStyle::CE_ToolButtonLabel, p, this, rect( ), colorGroup( ),
+ tqstyle( ).tqdrawControl( TQStyle::CE_ToolButtonLabel, p, this, rect( ), tqcolorGroup( ),
TQStyle::Style_Enabled );
}
};
@@ -29,7 +29,7 @@
#include "pmdebug.h"
// Fixed widths are calculated wrong in a toolbar.
-// Fixed sizeHint for the combo box to return
+// Fixed tqsizeHint for the combo box to return
// at least the minimum size
class PMComboBox : public TQComboBox